@@ -1,6 +1,7 @@
 from typing import List
 
-from langchain_community.agent_toolkits.base import BaseToolkit
+from langchain_core.tools import BaseToolkit
+
 from langchain_community.tools import BaseTool
 from langchain_community.tools.cogniswitch.tool import (
     CogniswitchKnowledgeRequest,
