@@ -1,8 +1,10 @@
 from typing import List
 
-from langchain_community.agent_toolkits.base import BaseToolkit
+from langchain_core.tools import BaseToolkit
+
 from langchain_community.tools import BaseTool
 from langchain_community.tools.polygon import (
+    PolygonAggregates,
     PolygonFinancials,
     PolygonLastQuote,
     PolygonTickerNews,
@@ -20,6 +22,9 @@ class PolygonToolkit(BaseToolkit):
         cls, polygon_api_wrapper: PolygonAPIWrapper
     ) -> "PolygonToolkit":
         tools = [
+            PolygonAggregates(
+                api_wrapper=polygon_api_wrapper,
+            ),
             PolygonLastQuote(
                 api_wrapper=polygon_api_wrapper,
             ),
