@@ -1,27 +1,22 @@
 import json
-import logging
 from pathlib import Path
 from typing import List
 
-from langchain_core.chat_history import BaseChatMessageHistory
-from langchain_core.messages import (
-    BaseMessage,
-    messages_from_dict,
-    messages_to_dict,
+from langchain_core.chat_history import (
+    BaseChatMessageHistory,
 )
-
-logger = logging.getLogger(__name__)
+from langchain_core.messages import BaseMessage, messages_from_dict, messages_to_dict
 
 
 class FileChatMessageHistory(BaseChatMessageHistory):
-    """
-    Chat message history that stores history in a local file.
+    """Chat message history that stores history in a local file."""
 
-    Args:
-        file_path: path of the local file to store the messages.
-    """
+    def __init__(self, file_path: str) -> None:
+        """Initialize the file path for the chat history.
 
-    def __init__(self, file_path: str):
+        Args:
+            file_path: The path to the local file to store the chat history.
+        """
         self.file_path = Path(file_path)
         if not self.file_path.exists():
             self.file_path.touch()
