@@ -1,5 +1,6 @@
 from typing import Any, AsyncIterator, Dict, Iterator, List, Optional, cast
 
+from langchain_core._api.deprecation import deprecated
 from langchain_core.callbacks import (
     AsyncCallbackManagerForLLMRun,
     CallbackManagerForLLMRun,
@@ -70,6 +71,11 @@ def convert_messages_to_prompt_anthropic(
     return text.rstrip()
 
 
+@deprecated(
+    since="0.0.28",
+    removal="0.3",
+    alternative_import="langchain_anthropic.ChatAnthropic",
+)
 class ChatAnthropic(BaseChatModel, _AnthropicCommon):
     """`Anthropic` chat large language models.
 
