@@ -1,5 +1,6 @@
 import json
-from typing import List
+from pathlib import Path
+from typing import List, Union
 
 from langchain_core.documents import Document
 from langchain_core.utils import stringify_dict
@@ -10,7 +11,7 @@ from langchain_community.document_loaders.base import BaseLoader
 class AirbyteJSONLoader(BaseLoader):
     """Load local `Airbyte` json files."""
 
-    def __init__(self, file_path: str):
+    def __init__(self, file_path: Union[str, Path]):
         """Initialize with a file path. This should start with '/tmp/airbyte_local/'."""
         self.file_path = file_path
         """Path to the directory containing the json files."""
@@ -20,5 +21,5 @@ class AirbyteJSONLoader(BaseLoader):
         for line in open(self.file_path, "r"):
             data = json.loads(line)["_airbyte_data"]
             text += stringify_dict(data)
-        metadata = {"source": self.file_path}
+        metadata = {"source": str(self.file_path)}
         return [Document(page_content=text, metadata=metadata)]
