@@ -2,6 +2,7 @@ import os
 import tempfile
 from typing import Callable, List, Optional
 
+from langchain_core._api.deprecation import deprecated
 from langchain_core.documents import Document
 
 from langchain_community.document_loaders.base import BaseLoader
@@ -9,6 +10,11 @@ from langchain_community.document_loaders.unstructured import UnstructuredFileLo
 from langchain_community.utilities.vertexai import get_client_info
 
 
+@deprecated(
+    since="0.0.32",
+    removal="0.3.0",
+    alternative_import="langchain_google_community.GCSFileLoader",
+)
 class GCSFileLoader(BaseLoader):
     """Load from GCS file."""
 
