@@ -10,6 +10,6 @@ from langchain_community.document_loaders.blob_loaders import Blob
 class TextParser(BaseBlobParser):
     """Parser for text blobs."""
 
-    def lazy_parse(self, blob: Blob) -> Iterator[Document]:
+    def lazy_parse(self, blob: Blob) -> Iterator[Document]:  # type: ignore[valid-type]
         """Lazily parse the blob."""
-        yield Document(page_content=blob.as_string(), metadata={"source": blob.source})
+        yield Document(page_content=blob.as_string(), metadata={"source": blob.source})  # type: ignore[attr-defined]
