@@ -21,7 +21,9 @@ def _litm_reordering(documents: List[Document]) -> List[Document]:
 
 
 class LongContextReorder(BaseDocumentTransformer, BaseModel):
-    """Lost in the middle:
+    """Reorder long context.
+
+    Lost in the middle:
     Performance degrades when models must access relevant information
     in the middle of long contexts.
     See: https://arxiv.org/abs//2307.03172"""
