@@ -1,10 +1,18 @@
 from typing import Any, Dict, List, Optional
 
+from langchain_core._api.deprecation import deprecated
 from langchain_core.embeddings import Embeddings
 from langchain_core.pydantic_v1 import BaseModel, Extra, root_validator
 from langchain_core.utils import get_from_dict_or_env
 
+from langchain_community.llms.cohere import _create_retry_decorator
 
+
+@deprecated(
+    since="0.0.30",
+    removal="0.3.0",
+    alternative_import="langchain_cohere.CohereEmbeddings",
+)
 class CohereEmbeddings(BaseModel, Embeddings):
     """Cohere embedding models.
 
@@ -34,7 +42,7 @@ class CohereEmbeddings(BaseModel, Embeddings):
 
     cohere_api_key: Optional[str] = None
 
-    max_retries: Optional[int] = 3
+    max_retries: int = 3
     """Maximum number of retries to make when generating."""
     request_timeout: Optional[float] = None
     """Timeout in seconds for the Cohere API request."""
@@ -52,7 +60,6 @@ class CohereEmbeddings(BaseModel, Embeddings):
         cohere_api_key = get_from_dict_or_env(
             values, "cohere_api_key", "COHERE_API_KEY"
         )
-        max_retries = values.get("max_retries")
         request_timeout = values.get("request_timeout")
 
         try:
@@ -61,27 +68,45 @@ class CohereEmbeddings(BaseModel, Embeddings):
             client_name = values["user_agent"]
             values["client"] = cohere.Client(
                 cohere_api_key,
-                max_retries=max_retries,
                 timeout=request_timeout,
                 client_name=client_name,
             )
             values["async_client"] = cohere.AsyncClient(
                 cohere_api_key,
-                max_retries=max_retries,
                 timeout=request_timeout,
                 client_name=client_name,
             )
         except ImportError:
-            raise ValueError(
+            raise ImportError(
                 "Could not import cohere python package. "
                 "Please install it with `pip install cohere`."
             )
         return values
 
+    def embed_with_retry(self, **kwargs: Any) -> Any:
+        """Use tenacity to retry the embed call."""
+        retry_decorator = _create_retry_decorator(self.max_retries)
+
+        @retry_decorator
+        def _embed_with_retry(**kwargs: Any) -> Any:
+            return self.client.embed(**kwargs)
+
+        return _embed_with_retry(**kwargs)
+
+    def aembed_with_retry(self, **kwargs: Any) -> Any:
+        """Use tenacity to retry the embed call."""
+        retry_decorator = _create_retry_decorator(self.max_retries)
+
+        @retry_decorator
+        async def _embed_with_retry(**kwargs: Any) -> Any:
+            return await self.async_client.embed(**kwargs)
+
+        return _embed_with_retry(**kwargs)
+
     def embed(
         self, texts: List[str], *, input_type: Optional[str] = None
     ) -> List[List[float]]:
-        embeddings = self.client.embed(
+        embeddings = self.embed_with_retry(
             model=self.model,
             texts=texts,
             input_type=input_type,
@@ -93,7 +118,7 @@ class CohereEmbeddings(BaseModel, Embeddings):
         self, texts: List[str], *, input_type: Optional[str] = None
     ) -> List[List[float]]:
         embeddings = (
-            await self.async_client.embed(
+            await self.aembed_with_retry(
                 model=self.model,
                 texts=texts,
                 input_type=input_type,
