@@ -114,6 +114,12 @@ def _import_bedrock() -> Type[BaseLLM]:
     return Bedrock
 
 
+def _import_bigdlllm() -> Type[BaseLLM]:
+    from langchain_community.llms.bigdl_llm import BigdlLLM
+
+    return BigdlLLM
+
+
 def _import_bittensor() -> Type[BaseLLM]:
     from langchain_community.llms.bittensor import NIBittensorLLM
 
@@ -162,10 +168,11 @@ def _import_databricks() -> Type[BaseLLM]:
     return Databricks
 
 
+# deprecated / only for back compat - do not add to __all__
 def _import_databricks_chat() -> Any:
     warn_deprecated(
         since="0.0.22",
-        removal="0.2",
+        removal="0.3",
         alternative_import="langchain_community.chat_models.ChatDatabricks",
     )
     from langchain_community.chat_models.databricks import ChatDatabricks
@@ -209,6 +216,12 @@ def _import_forefrontai() -> Type[BaseLLM]:
     return ForefrontAI
 
 
+def _import_friendli() -> Type[BaseLLM]:
+    from langchain_community.llms.friendli import Friendli
+
+    return Friendli
+
+
 def _import_gigachat() -> Type[BaseLLM]:
     from langchain_community.llms.gigachat import GigaChat
 
@@ -271,6 +284,12 @@ def _import_human() -> Type[BaseLLM]:
     return HumanInputLLM
 
 
+def _import_ipex_llm() -> Type[BaseLLM]:
+    from langchain_community.llms.ipex_llm import IpexLLM
+
+    return IpexLLM
+
+
 def _import_javelin_ai_gateway() -> Type[BaseLLM]:
     from langchain_community.llms.javelin_ai_gateway import JavelinAIGateway
 
@@ -319,10 +338,11 @@ def _import_mlflow() -> Type[BaseLLM]:
     return Mlflow
 
 
+# deprecated / only for back compat - do not add to __all__
 def _import_mlflow_chat() -> Any:
     warn_deprecated(
         since="0.0.22",
-        removal="0.2",
+        removal="0.3",
         alternative_import="langchain_community.chat_models.ChatMlflow",
     )
     from langchain_community.chat_models.mlflow import ChatMlflow
@@ -336,6 +356,12 @@ def _import_mlflow_ai_gateway() -> Type[BaseLLM]:
     return MlflowAIGateway
 
 
+def _import_mlx_pipeline() -> Type[BaseLLM]:
+    from langchain_community.llms.mlx_pipeline import MLXPipeline
+
+    return MLXPipeline
+
+
 def _import_modal() -> Type[BaseLLM]:
     from langchain_community.llms.modal import Modal
 
@@ -484,6 +510,18 @@ def _import_sagemaker_endpoint() -> Type[BaseLLM]:
     return SagemakerEndpoint
 
 
+def _import_sambaverse() -> Type[BaseLLM]:
+    from langchain_community.llms.sambanova import Sambaverse
+
+    return Sambaverse
+
+
+def _import_sambastudio() -> Type[BaseLLM]:
+    from langchain_community.llms.sambanova import SambaStudio
+
+    return SambaStudio
+
+
 def _import_self_hosted() -> Type[BaseLLM]:
     from langchain_community.llms.self_hosted import SelfHostedPipeline
 
@@ -523,9 +561,9 @@ def _import_titan_takeoff() -> Type[BaseLLM]:
 
 
 def _import_titan_takeoff_pro() -> Type[BaseLLM]:
-    from langchain_community.llms.titan_takeoff_pro import TitanTakeoffPro
+    from langchain_community.llms.titan_takeoff import TitanTakeoff
 
-    return TitanTakeoffPro
+    return TitanTakeoff
 
 
 def _import_together() -> Type[BaseLLM]:
@@ -570,6 +608,14 @@ def _import_watsonxllm() -> Type[BaseLLM]:
     return WatsonxLLM
 
 
+def _import_weight_only_quantization() -> Any:
+    from langchain_community.llms.weight_only_quantization import (
+        WeightOnlyQuantPipeline,
+    )
+
+    return WeightOnlyQuantPipeline
+
+
 def _import_writer() -> Type[BaseLLM]:
     from langchain_community.llms.writer import Writer
 
@@ -625,7 +671,7 @@ def __getattr__(name: str) -> Any:
         return _import_aviary()
     elif name == "AzureMLOnlineEndpoint":
         return _import_azureml_endpoint()
-    elif name == "Baichuan":
+    elif name == "BaichuanLLM" or name == "Baichuan":
         return _import_baichuan()
     elif name == "QianfanLLMEndpoint":
         return _import_baidu_qianfan_endpoint()
@@ -637,6 +683,8 @@ def __getattr__(name: str) -> Any:
         return _import_beam()
     elif name == "Bedrock":
         return _import_bedrock()
+    elif name == "BigdlLLM":
+        return _import_bigdlllm()
     elif name == "NIBittensorLLM":
         return _import_bittensor()
     elif name == "CerebriumAI":
@@ -665,6 +713,8 @@ def __getattr__(name: str) -> Any:
         return _import_fireworks()
     elif name == "ForefrontAI":
         return _import_forefrontai()
+    elif name == "Friendli":
+        return _import_friendli()
     elif name == "GigaChat":
         return _import_gigachat()
     elif name == "GooglePalm":
@@ -685,6 +735,8 @@ def __getattr__(name: str) -> Any:
         return _import_huggingface_text_gen_inference()
     elif name == "HumanInputLLM":
         return _import_human()
+    elif name == "IpexLLM":
+        return _import_ipex_llm()
     elif name == "JavelinAIGateway":
         return _import_javelin_ai_gateway()
     elif name == "KoboldApiLLM":
@@ -693,6 +745,8 @@ def __getattr__(name: str) -> Any:
         return _import_konko()
     elif name == "LlamaCpp":
         return _import_llamacpp()
+    elif name == "Llamafile":
+        return _import_llamafile()
     elif name == "ManifestWrapper":
         return _import_manifest()
     elif name == "Minimax":
@@ -701,6 +755,8 @@ def __getattr__(name: str) -> Any:
         return _import_mlflow()
     elif name == "MlflowAIGateway":
         return _import_mlflow_ai_gateway()
+    elif name == "MLXPipeline":
+        return _import_mlx_pipeline()
     elif name == "Modal":
         return _import_modal()
     elif name == "MosaicML":
@@ -749,6 +805,10 @@ def __getattr__(name: str) -> Any:
         return _import_rwkv()
     elif name == "SagemakerEndpoint":
         return _import_sagemaker_endpoint()
+    elif name == "Sambaverse":
+        return _import_sambaverse()
+    elif name == "SambaStudio":
+        return _import_sambastudio()
     elif name == "SelfHostedPipeline":
         return _import_self_hosted()
     elif name == "SelfHostedHuggingFaceLLM":
@@ -777,6 +837,8 @@ def __getattr__(name: str) -> Any:
         return _import_vllm_openai()
     elif name == "WatsonxLLM":
         return _import_watsonxllm()
+    elif name == "WeightOnlyQuantPipeline":
+        return _import_weight_only_quantization()
     elif name == "Writer":
         return _import_writer()
     elif name == "Xinference":
@@ -810,6 +872,7 @@ __all__ = [
     "Aviary",
     "AzureMLOnlineEndpoint",
     "AzureOpenAI",
+    "BaichuanLLM",
     "Banana",
     "Baseten",
     "Beam",
@@ -827,8 +890,9 @@ __all__ = [
     "FakeListLLM",
     "Fireworks",
     "ForefrontAI",
-    "GigaChat",
+    "Friendli",
     "GPT4All",
+    "GigaChat",
     "GooglePalm",
     "GooseAI",
     "GradientLLM",
@@ -837,22 +901,28 @@ __all__ = [
     "HuggingFacePipeline",
     "HuggingFaceTextGenInference",
     "HumanInputLLM",
+    "IpexLLM",
+    "JavelinAIGateway",
     "KoboldApiLLM",
     "Konko",
     "LlamaCpp",
-    "TextGen",
+    "Llamafile",
     "ManifestWrapper",
     "Minimax",
+    "Mlflow",
     "MlflowAIGateway",
+    "MLXPipeline",
     "Modal",
     "MosaicML",
-    "Nebula",
     "NIBittensorLLM",
     "NLPCloud",
+    "Nebula",
+    "OCIGenAI",
     "OCIModelDeploymentTGI",
     "OCIModelDeploymentVLLM",
-    "OCIGenAI",
+    "OctoAIEndpoint",
     "Ollama",
+    "OpaquePrompts",
     "OpenAI",
     "OpenAIChat",
     "OpenLLM",
@@ -864,30 +934,32 @@ __all__ = [
     "PredictionGuard",
     "PromptLayerOpenAI",
     "PromptLayerOpenAIChat",
-    "OpaquePrompts",
+    "QianfanLLMEndpoint",
     "RWKV",
     "Replicate",
     "SagemakerEndpoint",
+    "Sambaverse",
+    "SambaStudio",
     "SelfHostedHuggingFaceLLM",
     "SelfHostedPipeline",
+    "SparkLLM",
     "StochasticAI",
+    "TextGen",
     "TitanTakeoff",
     "TitanTakeoffPro",
+    "Together",
     "Tongyi",
-    "VertexAI",
-    "VertexAIModelGarden",
     "VLLM",
     "VLLMOpenAI",
+    "VertexAI",
+    "VertexAIModelGarden",
+    "VolcEngineMaasLLM",
     "WatsonxLLM",
+    "WeightOnlyQuantPipeline",
     "Writer",
-    "OctoAIEndpoint",
     "Xinference",
-    "JavelinAIGateway",
-    "QianfanLLMEndpoint",
     "YandexGPT",
     "Yuan2",
-    "VolcEngineMaasLLM",
-    "SparkLLM",
 ]
 
 
@@ -903,6 +975,7 @@ def get_type_to_cls_dict() -> Dict[str, Callable[[], Type[BaseLLM]]]:
         "aviary": _import_aviary,
         "azure": _import_azure_openai,
         "azureml_endpoint": _import_azureml_endpoint,
+        "baichuan": _import_baichuan,
         "bananadev": _import_bananadev,
         "baseten": _import_baseten,
         "beam": _import_beam,
@@ -913,12 +986,13 @@ def get_type_to_cls_dict() -> Dict[str, Callable[[], Type[BaseLLM]]]:
         "ctransformers": _import_ctransformers,
         "ctranslate2": _import_ctranslate2,
         "databricks": _import_databricks,
-        "databricks-chat": _import_databricks_chat,
+        "databricks-chat": _import_databricks_chat,  # deprecated / only for back compat
         "deepinfra": _import_deepinfra,
         "deepsparse": _import_deepsparse,
         "edenai": _import_edenai,
         "fake-list": _import_fake,
         "forefrontai": _import_forefrontai,
+        "friendli": _import_friendli,
         "giga-chat-model": _import_gigachat,
         "google_palm": _import_google_palm,
         "gooseai": _import_gooseai,
@@ -932,11 +1006,13 @@ def get_type_to_cls_dict() -> Dict[str, Callable[[], Type[BaseLLM]]]:
         "koboldai": _import_koboldai,
         "konko": _import_konko,
         "llamacpp": _import_llamacpp,
+        "llamafile": _import_llamafile,
         "textgen": _import_textgen,
         "minimax": _import_minimax,
         "mlflow": _import_mlflow,
-        "mlflow-chat": _import_mlflow_chat,
+        "mlflow-chat": _import_mlflow_chat,  # deprecated / only for back compat
         "mlflow-ai-gateway": _import_mlflow_ai_gateway,
+        "mlx_pipeline": _import_mlx_pipeline,
         "modal": _import_modal,
         "mosaic": _import_mosaicml,
         "nebula": _import_symblai_nebula,
@@ -945,6 +1021,7 @@ def get_type_to_cls_dict() -> Dict[str, Callable[[], Type[BaseLLM]]]:
         "oci_model_deployment_tgi_endpoint": _import_oci_md_tgi,
         "oci_model_deployment_vllm_endpoint": _import_oci_md_vllm,
         "oci_generative_ai": _import_oci_gen_ai,
+        "octoai_endpoint": _import_octoai_endpoint,
         "ollama": _import_ollama,
         "openai": _import_openai,
         "openlm": _import_openlm,
@@ -956,6 +1033,8 @@ def get_type_to_cls_dict() -> Dict[str, Callable[[], Type[BaseLLM]]]:
         "replicate": _import_replicate,
         "rwkv": _import_rwkv,
         "sagemaker_endpoint": _import_sagemaker_endpoint,
+        "sambaverse": _import_sambaverse,
+        "sambastudio": _import_sambastudio,
         "self_hosted": _import_self_hosted,
         "self_hosted_hugging_face": _import_self_hosted_hugging_face,
         "stochasticai": _import_stochasticai,
@@ -970,6 +1049,7 @@ def get_type_to_cls_dict() -> Dict[str, Callable[[], Type[BaseLLM]]]:
         "vllm": _import_vllm,
         "vllm_openai": _import_vllm_openai,
         "watsonxllm": _import_watsonxllm,
+        "weight_only_quantization": _import_weight_only_quantization,
         "writer": _import_writer,
         "xinference": _import_xinference,
         "javelin-ai-gateway": _import_javelin_ai_gateway,
