@@ -11,6 +11,7 @@ from typing import (
     Optional,
 )
 
+from langchain_core._api.deprecation import deprecated
 from langchain_core.callbacks import (
     AsyncCallbackManagerForLLMRun,
     CallbackManagerForLLMRun,
@@ -147,6 +148,11 @@ class _AnthropicCommon(BaseLanguageModel):
         return stop
 
 
+@deprecated(
+    since="0.0.28",
+    removal="0.3",
+    alternative_import="langchain_anthropic.AnthropicLLM",
+)
 class Anthropic(LLM, _AnthropicCommon):
     """Anthropic large language models.
 
@@ -164,13 +170,13 @@ class Anthropic(LLM, _AnthropicCommon):
 
             # Simplest invocation, automatically wrapped with HUMAN_PROMPT
             # and AI_PROMPT.
-            response = model("What are the biggest risks facing humanity?")
+            response = model.invoke("What are the biggest risks facing humanity?")
 
             # Or if you want to use the chat mode, build a few-shot-prompt, or
             # put words in the Assistant's mouth, use HUMAN_PROMPT and AI_PROMPT:
             raw_prompt = "What are the biggest risks facing humanity?"
             prompt = f"{anthropic.HUMAN_PROMPT} {prompt}{anthropic.AI_PROMPT}"
-            response = model(prompt)
+            response = model.invoke(prompt)
     """
 
     class Config:
@@ -230,7 +236,7 @@ class Anthropic(LLM, _AnthropicCommon):
 
                 prompt = "What are the biggest risks facing humanity?"
                 prompt = f"\n\nHuman: {prompt}\n\nAssistant:"
-                response = model(prompt)
+                response = model.invoke(prompt)
 
         """
         if self.streaming:
