@@ -40,12 +40,12 @@ stream_completion_with_retry = None
 
 
 def is_codey_model(model_name: str) -> bool:
-    """Returns True if the model name is a Codey model."""
+    """Return True if the model name is a Codey model."""
     return "code" in model_name
 
 
 def is_gemini_model(model_name: str) -> bool:
-    """Returns True if the model name is a Gemini model."""
+    """Return True if the model name is a Gemini model."""
     return model_name is not None and "gemini" in model_name
 
 
@@ -203,7 +203,7 @@ class _VertexAICommon(_VertexAIBase):
 
 @deprecated(
     since="0.0.12",
-    removal="0.2.0",
+    removal="0.3.0",
     alternative_import="langchain_google_vertexai.VertexAI",
 )
 class VertexAI(_VertexAICommon, BaseLLM):
@@ -363,7 +363,7 @@ class VertexAI(_VertexAICommon, BaseLLM):
             generations.append(
                 [self._response_to_generation(r) for r in res.candidates]
             )
-        return LLMResult(generations=generations)
+        return LLMResult(generations=generations)  # type: ignore[arg-type]
 
     def _stream(
         self,
@@ -393,11 +393,11 @@ class VertexAI(_VertexAICommon, BaseLLM):
 
 @deprecated(
     since="0.0.12",
-    removal="0.2.0",
+    removal="0.3.0",
     alternative_import="langchain_google_vertexai.VertexAIModelGarden",
 )
 class VertexAIModelGarden(_VertexAIBase, BaseLLM):
-    """Large language models served from Vertex AI Model Garden."""
+    """Vertex AI Model Garden large language models."""
 
     client: "PredictionServiceClient" = None  #: :meta private:
     async_client: "PredictionServiceAsyncClient" = None  #: :meta private:
