@@ -2,8 +2,9 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Tuple
 
+from langchain_core._api.deprecation import deprecated
 from langchain_core.callbacks import CallbackManagerForRetrieverRun
 from langchain_core.documents import Document
 from langchain_core.pydantic_v1 import BaseModel, Extra, Field, root_validator
@@ -25,8 +26,10 @@ if TYPE_CHECKING:
 class _BaseGoogleVertexAISearchRetriever(BaseModel):
     project_id: str
     """Google Cloud Project ID."""
-    data_store_id: str
+    data_store_id: Optional[str] = None
     """Vertex AI Search data store ID."""
+    search_engine_id: Optional[str] = None
+    """Vertex AI Search app ID."""
     location_id: str = "global"
     """Vertex AI Search data store location."""
     serving_config_id: str = "default_config"
@@ -35,11 +38,12 @@ class _BaseGoogleVertexAISearchRetriever(BaseModel):
     """The default custom credentials (google.auth.credentials.Credentials) to use
     when making API calls. If not provided, credentials will be ascertained from
     the environment."""
-    engine_data_type: int = Field(default=0, ge=0, le=2)
-    """ Defines the Vertex AI Search data type
+    engine_data_type: int = Field(default=0, ge=0, le=3)
+    """ Defines the Vertex AI Search app data type
     0 - Unstructured data 
     1 - Structured data
     2 - Website data
+    3 - Blended search
     """
 
     @root_validator(pre=True)
@@ -51,7 +55,7 @@ class _BaseGoogleVertexAISearchRetriever(BaseModel):
             raise ImportError(
                 "google.cloud.discoveryengine is not installed."
                 "Please install it with pip install "
-                "google-cloud-discoveryengine>=0.11.0"
+                "google-cloud-discoveryengine>=0.11.10"
             ) from exc
         try:
             from google.api_core.exceptions import InvalidArgument  # noqa: F401
@@ -64,26 +68,15 @@ class _BaseGoogleVertexAISearchRetriever(BaseModel):
         values["project_id"] = get_from_dict_or_env(values, "project_id", "PROJECT_ID")
 
         try:
-            # For backwards compatibility
-            search_engine_id = get_from_dict_or_env(
+            values["data_store_id"] = get_from_dict_or_env(
+                values, "data_store_id", "DATA_STORE_ID"
+            )
+            values["search_engine_id"] = get_from_dict_or_env(
                 values, "search_engine_id", "SEARCH_ENGINE_ID"
             )
-
-            if search_engine_id:
-                import warnings
-
-                warnings.warn(
-                    "The `search_engine_id` parameter is deprecated. Use `data_store_id` instead.",  # noqa: E501
-                    DeprecationWarning,
-                )
-                values["data_store_id"] = search_engine_id
-        except:  # noqa: E722
+        except Exception:
             pass
 
-        values["data_store_id"] = get_from_dict_or_env(
-            values, "data_store_id", "DATA_STORE_ID"
-        )
-
         return values
 
     @property
@@ -145,14 +138,15 @@ class _BaseGoogleVertexAISearchRetriever(BaseModel):
                 continue
 
             for chunk in derived_struct_data[chunk_type]:
-                doc_metadata["source"] = derived_struct_data.get("link", "")
+                chunk_metadata = doc_metadata.copy()
+                chunk_metadata["source"] = derived_struct_data.get("link", "")
 
                 if chunk_type == "extractive_answers":
-                    doc_metadata["source"] += f":{chunk.get('pageNumber', '')}"
+                    chunk_metadata["source"] += f":{chunk.get('pageNumber', '')}"
 
                 documents.append(
                     Document(
-                        page_content=chunk.get("content", ""), metadata=doc_metadata
+                        page_content=chunk.get("content", ""), metadata=chunk_metadata
                     )
                 )
 
@@ -196,12 +190,17 @@ class _BaseGoogleVertexAISearchRetriever(BaseModel):
                 print(  # noqa: T201
                     "Make sure that your data store is using Advanced Website "
                     "Indexing.\n"
-                    "https://cloud.google.com/generative-ai-app-builder/docs/about-advanced-features#advanced-website-indexing"  # noqa: E501
+                    "https://cloud.google.com/generative-ai-app-builder/docs/about-advanced-features#advanced-website-indexing"
                 )
 
         return documents
 
 
+@deprecated(
+    since="0.0.33",
+    removal="0.3.0",
+    alternative_import="langchain_google_community.VertexAISearchRetriever",
+)
 class GoogleVertexAISearchRetriever(BaseRetriever, _BaseGoogleVertexAISearchRetriever):
     """`Google Vertex AI Search` retriever.
 
@@ -273,12 +272,24 @@ class GoogleVertexAISearchRetriever(BaseRetriever, _BaseGoogleVertexAISearchRetr
             client_info=get_client_info(module="vertex-ai-search"),
         )
 
-        self._serving_config = self._client.serving_config_path(
-            project=self.project_id,
-            location=self.location_id,
-            data_store=self.data_store_id,
-            serving_config=self.serving_config_id,
-        )
+        if self.engine_data_type == 3 and not self.search_engine_id:
+            raise ValueError(
+                "search_engine_id must be specified for blended search apps."
+            )
+
+        if self.search_engine_id:
+            self._serving_config = f"projects/{self.project_id}/locations/{self.location_id}/collections/default_collection/engines/{self.search_engine_id}/servingConfigs/default_config"  # noqa: E501
+        elif self.data_store_id:
+            self._serving_config = self._client.serving_config_path(
+                project=self.project_id,
+                location=self.location_id,
+                data_store=self.data_store_id,
+                serving_config=self.serving_config_id,
+            )
+        else:
+            raise ValueError(
+                "Either data_store_id or search_engine_id must be specified."
+            )
 
     def _create_search_request(self, query: str) -> SearchRequest:
         """Prepares a SearchRequest object."""
@@ -310,7 +321,7 @@ class GoogleVertexAISearchRetriever(BaseRetriever, _BaseGoogleVertexAISearchRetr
             )
         elif self.engine_data_type == 1:
             content_search_spec = None
-        elif self.engine_data_type == 2:
+        elif self.engine_data_type in (2, 3):
             content_search_spec = SearchRequest.ContentSearchSpec(
                 extractive_content_spec=SearchRequest.ContentSearchSpec.ExtractiveContentSpec(
                     max_extractive_answer_count=self.max_extractive_answer_count,
@@ -322,7 +333,7 @@ class GoogleVertexAISearchRetriever(BaseRetriever, _BaseGoogleVertexAISearchRetr
         else:
             raise NotImplementedError(
                 "Only data store type 0 (Unstructured), 1 (Structured),"
-                "or 2 (Website) are supported currently."
+                "2 (Website), or 3 (Blended) are supported currently."
                 + f" Got {self.engine_data_type}"
             )
 
@@ -340,6 +351,11 @@ class GoogleVertexAISearchRetriever(BaseRetriever, _BaseGoogleVertexAISearchRetr
         self, query: str, *, run_manager: CallbackManagerForRetrieverRun
     ) -> List[Document]:
         """Get documents relevant for a query."""
+        return self.get_relevant_documents_with_response(query)[0]
+
+    def get_relevant_documents_with_response(
+        self, query: str
+    ) -> Tuple[List[Document], Any]:
         from google.api_core.exceptions import InvalidArgument
 
         search_request = self._create_search_request(query)
@@ -363,7 +379,7 @@ class GoogleVertexAISearchRetriever(BaseRetriever, _BaseGoogleVertexAISearchRetr
             )
         elif self.engine_data_type == 1:
             documents = self._convert_structured_search_response(response.results)
-        elif self.engine_data_type == 2:
+        elif self.engine_data_type in (2, 3):
             chunk_type = (
                 "extractive_answers" if self.get_extractive_answers else "snippets"
             )
@@ -373,13 +389,18 @@ class GoogleVertexAISearchRetriever(BaseRetriever, _BaseGoogleVertexAISearchRetr
         else:
             raise NotImplementedError(
                 "Only data store type 0 (Unstructured), 1 (Structured),"
-                "or 2 (Website) are supported currently."
+                "2 (Website), or 3 (Blended) are supported currently."
                 + f" Got {self.engine_data_type}"
             )
 
-        return documents
+        return documents, response
 
 
+@deprecated(
+    since="0.0.33",
+    removal="0.3.0",
+    alternative_import="langchain_google_community.VertexAIMultiTurnSearchRetriever",
+)
 class GoogleVertexAIMultiTurnSearchRetriever(
     BaseRetriever, _BaseGoogleVertexAISearchRetriever
 ):
@@ -410,6 +431,9 @@ class GoogleVertexAIMultiTurnSearchRetriever(
             client_info=get_client_info(module="vertex-ai-search"),
         )
 
+        if not self.data_store_id:
+            raise ValueError("data_store_id is required for MultiTurnSearchRetriever.")
+
         self._serving_config = self._client.serving_config_path(
             project=self.project_id,
             location=self.location_id,
@@ -417,9 +441,9 @@ class GoogleVertexAIMultiTurnSearchRetriever(
             serving_config=self.serving_config_id,
         )
 
-        if self.engine_data_type == 1:
+        if self.engine_data_type == 1 or self.engine_data_type == 3:
             raise NotImplementedError(
-                "Data store type 1 (Structured)"
+                "Data store type 1 (Structured) and 3 (Blended)"
                 "is not currently supported for multi-turn search."
                 + f" Got {self.engine_data_type}"
             )
