@@ -13,10 +13,10 @@ class OpenWeatherMapQueryRun(BaseTool):
     """Tool that queries the OpenWeatherMap API."""
 
     api_wrapper: OpenWeatherMapAPIWrapper = Field(
-        default_factory=OpenWeatherMapAPIWrapper
+        default_factory=OpenWeatherMapAPIWrapper  # type: ignore[arg-type]
     )
 
-    name: str = "OpenWeatherMap"
+    name: str = "open_weather_map"
     description: str = (
         "A wrapper around OpenWeatherMap API. "
         "Useful for fetching current weather information for a specified location. "
