@@ -12,11 +12,13 @@ from langchain_community.utilities.you import YouSearchAPIWrapper
 
 
 class YouInput(BaseModel):
+    """Input schema for the you.com tool."""
+
     query: str = Field(description="should be a search query")
 
 
 class YouSearchTool(BaseTool):
-    """Tool that searches the you.com API"""
+    """Tool that searches the you.com API."""
 
     name = "you_search"
     description = (
