@@ -10,6 +10,7 @@ from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple
 import numpy as np
 from langchain_core.documents import Document
 from langchain_core.embeddings import Embeddings
+from langchain_core.utils import guard_import
 from langchain_core.vectorstores import VectorStore
 
 from langchain_community.docstore.base import Docstore
@@ -22,14 +23,7 @@ DEFAULT_METRIC = "angular"
 
 def dependable_annoy_import() -> Any:
     """Import annoy if available, otherwise raise error."""
-    try:
-        import annoy
-    except ImportError:
-        raise ImportError(
-            "Could not import annoy python package. "
-            "Please install it with `pip install --user annoy` "
-        )
-    return annoy
+    return guard_import("annoy")
 
 
 class Annoy(VectorStore):
@@ -300,7 +294,7 @@ class Annoy(VectorStore):
                     f"Expected one of {list(INDEX_METRICS)}"
                 )
             )
-        annoy = dependable_annoy_import()
+        annoy = guard_import("annoy")
         if not embeddings:
             raise ValueError("embeddings must be provided to build AnnoyIndex")
         f = len(embeddings[0])
@@ -452,14 +446,14 @@ class Annoy(VectorStore):
                 "You will need to set `allow_dangerous_deserialization` to `True` to "
                 "enable deserialization. If you do this, make sure that you "
                 "trust the source of the data. For example, if you are loading a "
-                "file that you created, and no that no one else has modified the file, "
-                "then this is safe to do. Do not set this to `True` if you are loading "
-                "a file from an untrusted source (e.g., some random site on the "
-                "internet.)."
+                "file that you created, and know that no one else has modified the "
+                "file, then this is safe to do. Do not set this to `True` if you are "
+                "loading a file from an untrusted source (e.g., some random site on "
+                "the internet.)."
             )
         path = Path(folder_path)
         # load index separately since it is not picklable
-        annoy = dependable_annoy_import()
+        annoy = guard_import("annoy")
         # load docstore and index_to_docstore_id
         with open(path / "index.pkl", "rb") as file:
             docstore, index_to_docstore_id, config_object = pickle.load(file)
